@@ -30,13 +30,14 @@ class PortfolioInfo:
                 left join "portfolio_cycle" t4 on t1."portfolioCycleId" = t4.id
         """, con=self.paper_trading_db_connection)
 
-    def update_target_percent_portfolio(self, portfolio_data: dict, cycle_length: int):
+    def update_target_percent_portfolio(self, portfolio_data: dict, cycle_length: int, portfolioModel: int):
 
         url = f"{self.paper_trading_api_end_point}/portfolioCycle/updateTargetPercent"
 
         payload = json.dumps({
             "ratio": portfolio_data,
-            "cycleLength": cycle_length
+            "cycleLength": cycle_length,
+            "portfolioModel": portfolioModel
         })
         headers = {
             'Content-Type': 'application/json'
